@@ -713,12 +713,9 @@ class Sale(
         if Transaction().context.get('modify_header'):
             attributes.extend([
                     ('//group[@id="states"]', 'states', {'invisible': True}),
-                    ('//group[@id="amount_buttons"]',
-                        'states', {'invisible': True}),
-                    ('//page[@name="invoices"]',
-                        'states', {'invisible': True}),
-                    ('//page[@name="shipments"]',
-                        'states', {'invisible': True}),
+                    ('//group[@id="amount"]', 'states', {'invisible': True}),
+                    ('//group[@id="links"]', 'states', {'invisible': True}),
+                    ('//group[@id="buttons"]', 'states', {'invisible': True}),
                     ])
         return attributes
 
@@ -928,6 +925,17 @@ class Sale(
                         sale=sale.rec_name))
         super(Sale, cls).delete(sales)
 
+    def on_change(self, fieldnames):
+        pool = Pool()
+        ModelData = pool.get('ir.model.data')
+        context = Transaction().context
+        wizard_modify_header_id = ModelData.get_id(
+            'sale', 'wizard_modify_header')
+        if (len(fieldnames) > 1
+                and context.get('action_id') == wizard_modify_header_id):
+            return []
+        return super().on_change(fieldnames)
+
     @classmethod
     @ModelView.button
     @Workflow.transition('cancelled')
